@@ -1,4 +1,4 @@
-# from .augment_signals import *
+from .augment_signals import *
 from .eigensystem_realization_algorithm import *
 from .eigensystem_realization_algorithm_from_initial_condition_response import *
 from .eigensystem_realization_algorithm_with_data_correlation import *
@@ -6,6 +6,7 @@ from .eigensystem_realization_algorithm_with_data_correlation_from_initial_condi
 from .mac_and_msv import *
 from .markov_parameters_from_observer_markov_parameters import *
 from .moments_propagation import *
+from .normalize import *
 from .observer_gain_markov_parameters_from_observer_markov_parameters import *
 from .observer_kalman_identification_algorithm import *
 from .observer_kalman_identification_algorithm_with_observer import *
