@@ -21,6 +21,7 @@ class discrete_signal:
         if len(self.data.shape) == 1:
             self.dimension = 1
             self.number_steps = int(self.data.shape[0])
+            self.data = np.expand_dims(self.data, axis=0)
         else:
             self.dimension = int(self.data.shape[0])
             self.number_steps = int(self.data.shape[1])
@@ -33,3 +34,5 @@ class discrete_signal:
 
         self.total_time = float((self.number_steps - 1) / self.frequency)
 
+# def normalize_signal(discrete_signal):
+#
\ No newline at end of file
